@@ -17,24 +17,25 @@
 
 #include "config.h"
 
-#include <new>
 #include <errno.h>
 #include <math.h>
-#include <string.h>
+#include <new>
 #include <stdio.h>
+#include <string.h>
 
-#include <QtGui/QProgressDialog>
-#include <QtCore/QThread>
-#include <QtCore/QTime>
-#include <QtGui/QWidget>
+#include <QApplication>
+#include <QProgressDialog>
+#include <QThread>
+#include <QTime>
+#include <QVariantList>
+#include <QWidget>
 
-#include <kapplication.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "libkwave/ConfirmCancelProxy.h"
 #include "libkwave/Plugin.h"
-#include "libkwave/Sample.h"
 #include "libkwave/PluginManager.h"
+#include "libkwave/Sample.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/String.h"
 #include "libkwave/Utils.h"
@@ -67,10 +68,11 @@
  */
 
 //***************************************************************************
-Kwave::Plugin::Plugin(Kwave::PluginManager &plugin_manager)
+Kwave::Plugin::Plugin(QObject *parent, const QVariantList &args)
     :QObject(0),
      Kwave::Runnable(),
-     m_plugin_manager(&plugin_manager),
+     m_plugin_manager(qobject_cast<Kwave::PluginManager *>(parent)),
+     m_name(args[0].toString()),
      m_thread(0),
      m_thread_lock(),
      m_progress_enabled(true),
@@ -83,6 +85,7 @@ Kwave::Plugin::Plugin(Kwave::PluginManager &plugin_manager)
      m_current_progress(-1),
      m_progress_lock(QMutex::Recursive)
 {
+    Q_ASSERT(m_plugin_manager);
     connect(&m_progress_timer, SIGNAL(timeout()),
             this, SLOT(updateProgressTick()),
             Qt::DirectConnection);
@@ -188,6 +191,12 @@ int Kwave::Plugin::start(QStringList &)
     return 0;
 }
 
+//***************************************************************************
+QString Kwave::Plugin::name() const
+{
+    return m_name;
+}
+
 //***************************************************************************
 QString Kwave::Plugin::progressText()
 {
@@ -211,7 +220,7 @@ int Kwave::Plugin::stop()
 	       reinterpret_cast<void *>(QThread::currentThread()),
 	       reinterpret_cast<void *>(m_thread));
 	void *buf[256];
-	size_t n = backtrace(buf, 256);
+	int n = backtrace(buf, 256);
 	backtrace_symbols_fd(buf, n, 2);
 #endif
 	return -EBUSY;
@@ -332,13 +341,13 @@ int Kwave::Plugin::execute(QStringList &params)
 }
 
 //***************************************************************************
-bool Kwave::Plugin::canClose()
+bool Kwave::Plugin::canClose() const
 {
     return !isRunning();
 }
 
 //***************************************************************************
-bool Kwave::Plugin::isRunning()
+bool Kwave::Plugin::isRunning() const
 {
     return (m_thread) && m_thread->isRunning();
 }
@@ -515,7 +524,5 @@ void Kwave::Plugin::setPluginManager(Kwave::PluginManager *new_plugin_manager)
 	m_confirm_cancel->setParent(m_plugin_manager->parentWidget());
 }
 
-//***************************************************************************
-#include "Plugin.moc"
 //***************************************************************************
 //***************************************************************************
