@@ -20,14 +20,16 @@
 
 #include "config.h"
 
-#include <QtCore/QList>
-#include <QtCore/QMutex>
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QThread>
-#include <QtCore/QTimer>
+#include <QtGlobal>
+#include <QList>
+#include <QMutex>
+#include <QObject>
+#include <QString>
+#include <QThread>
+#include <QTimer>
+#include <QVariantList>
 
-#include <kdemacros.h>
+#include <KPluginFactory>
 
 #include "libkwave/Runnable.h"
 #include "libkwave/Sample.h"
@@ -37,29 +39,17 @@ class QProgressDialog;
 class QStringList;
 class QVariant;
 
-#define KWAVE_PLUGIN(__class__,__name__,__version__,                          \
-                     __description__,__author__)                              \
-                                                                              \
-    extern "C" Kwave::Plugin *load(                                           \
-                     Kwave::PluginManager &plugin_manager) KDE_EXPORT;        \
-    extern "C" const char    *name                         KDE_EXPORT;        \
-    extern "C" const char    *version                      KDE_EXPORT;        \
-    extern "C" const char    *description                  KDE_EXPORT;        \
-    extern "C" const char    *author                       KDE_EXPORT;        \
-                                                                              \
-    extern "C" Kwave::Plugin *load(Kwave::PluginManager &plugin_manager) {    \
-	return new __class__(plugin_manager);                                 \
-    }                                                                         \
-                                                                              \
-    QString __class__::name() const                                           \
-    {                                                                         \
-	return _(__name__);                                                   \
-    }                                                                         \
-                                                                              \
-    const char *name        = __name__;                                       \
-    const char *version     = __version__;                                    \
-    const char *description = __description__;                                \
-    const char *author      = __author__
+/**
+ * @def KWAVE_PLUGIN(name,class)
+ * @param name short internal name of the plugin, used for the library
+ *             file name, in most cases identical to the directory name
+ * @param class name of the C++ class that implements the plugin, without
+ *              namespace
+ */
+#define KWAVE_PLUGIN(name,class)                               \
+    K_PLUGIN_FACTORY_WITH_JSON(kwaveplugin_##name##_factory,   \
+                               "kwaveplugin_"#name".json",     \
+                               registerPlugin<Kwave::class>();)
 
 namespace Kwave
 {
@@ -77,7 +67,7 @@ namespace Kwave
      * all necessary functions to access the functionality of the main
      * Kwave program.
      */
-    class KDE_EXPORT Plugin: public QObject, public Kwave::Runnable
+    class Q_DECL_EXPORT Plugin: public QObject, public Kwave::Runnable
     {
 	Q_OBJECT
 
@@ -85,9 +75,10 @@ namespace Kwave
 
 	/**
 	 * Constructor
-	 * @param plugin_manager reference to our plugin manager
+	 * @param parent pointer to our plugin manager
+	 * @param args argument list for initializing the plugin
 	 */
-	explicit Plugin(Kwave::PluginManager &plugin_manager);
+	Plugin(QObject *parent, const QVariantList &args);
 
 	/**
 	 * Destructor.
@@ -95,7 +86,7 @@ namespace Kwave
 	virtual ~Plugin();
 
 	/** Returns the name of the plugin. */
-	virtual QString name() const = 0;
+	virtual QString name() const;
 
 	/**
 	 * Returns a text for the progress dialog if enabled.
@@ -107,12 +98,12 @@ namespace Kwave
 	 * Returns true if the plugin can be closed.
 	 * The default implementation returns "!isRunning()"
 	 */
-	virtual bool canClose();
+	virtual bool canClose() const;
 
 	/**
 	 * Returns true if the plugin has a running thread.
 	 */
-	bool isRunning();
+	bool isRunning() const;
 
 	/**
 	 * Returns true if the plugin should stop, e.g. when the
@@ -346,6 +337,9 @@ namespace Kwave
 	/** reference to the plugin manager */
 	Kwave::PluginManager *m_plugin_manager;
 
+	/** name of the plugin, used for undo/redo */
+	QString m_name;
+
 	/**
 	 * Thread that executes the run() member function.
 	 */
