@@ -20,30 +20,36 @@
 #include <errno.h>
 #include <unistd.h>
 
-#include <QtGui/QApplication>
-#include <QtCore/QLatin1Char>
-#include <QtCore/QLibrary>
-#include <QtCore/QMutableListIterator>
+#include <QApplication>
+#include <QDir>
+#include <QLatin1Char>
+#include <QLibrary>
+#include <QLibraryInfo>
+#include <QMutableListIterator>
+#include <QtGlobal>
+#include <QVariantList>
 
-#include <kglobal.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kmainwindow.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMainWindow>
+#include <KPluginInfo>
+#include <KPluginFactory>
+#include <KPluginTrader>
+#include <KSharedConfig>
 
-#include "libkwave/Plugin.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MultiPlaybackSink.h"
 #include "libkwave/PlayBackDevice.h"
 #include "libkwave/PlaybackDeviceFactory.h"
+#include "libkwave/Plugin.h"
+#include "libkwave/PluginManager.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/Utils.h"
 #include "libkwave/Writer.h"
-#include "libkwave/undo/UndoTransactionGuard.h"
 #include "libkwave/undo/UndoAction.h"
 #include "libkwave/undo/UndoModifyAction.h"
-#include "libkwave/PluginManager.h"
+#include "libkwave/undo/UndoTransactionGuard.h"
 
 //***************************************************************************
 // static initializers
@@ -88,7 +94,7 @@ Kwave::PluginManager::~PluginManager()
     qApp->flush();
 
     // release all loaded modules
-    foreach (QString name, m_plugin_modules.keys()) {
+    foreach (const QString &name, m_plugin_modules.keys()) {
 	PluginModule &p = m_plugin_modules[name];
 	p.m_use_count--;
 
@@ -96,14 +102,14 @@ Kwave::PluginManager::~PluginManager()
 // 	       DBG(name), p.m_use_count);
 	if (p.m_use_count == 0) {
 	    // take out the pointer to the loadable module
-	    QLibrary *module = p.m_module;
-	    p.m_module = 0;
+	    KPluginFactory *factory = p.m_factory;
+	    p.m_factory = 0;
 
 	    // remove the module from the list
 	    m_plugin_modules.remove(name);
 
 	    // now the handle of the shared object can be released too
-	    if (module) delete module;
+	    if (factory) delete factory;
 	} else {
 	    // still in use
 	}
@@ -121,7 +127,7 @@ void Kwave::PluginManager::loadAllPlugins()
     // instance of the main window!
     // NOTE: this also gives each plugin the chance to stay in memory
     //       if necessary (e.g. for codecs)
-    foreach (QString name, m_plugin_modules.keys()) {
+    foreach (const QString &name, m_plugin_modules.keys()) {
 	KwavePluginPointer plugin = createPluginInstance(name);
 	if (plugin) {
 // 	    qDebug("PluginManager::loadAllPlugins(): plugin '%s'",
@@ -129,7 +135,7 @@ void Kwave::PluginManager::loadAllPlugins()
 
 	    // get the last settings and call the "load" function
 	    // now the plugin is present and loaded
-	    QStringList last_params = loadPluginDefaults(name);
+	    QStringList last_params = defaultParams(name);
 	    plugin->load(last_params);
 
 	    // reduce use count again, we loaded the plugin only to give
@@ -155,7 +161,7 @@ void Kwave::PluginManager::stopAllPlugins()
     Q_ASSERT(this->thread() == qApp->thread());
 
     if (!m_plugin_instances.isEmpty())
-	foreach (KwavePluginPointer plugin, m_plugin_instances)
+	foreach (const KwavePluginPointer &plugin, m_plugin_instances)
 	    if (plugin && plugin->isRunning())
 		plugin->stop() ;
 
@@ -181,8 +187,13 @@ Kwave::Plugin *Kwave::PluginManager::createPluginInstance(const QString &name)
 //     qDebug("loadPlugin(%s) [module use count=%d]",
 //         DBG(name), info.m_use_count);
 
+    KPluginFactory *factory = info.m_factory;
+    Q_ASSERT(factory);
+
     // call the loader function to create an instance
-    Kwave::Plugin *plugin = info.m_loader(*this);
+    QVariantList args;
+    args << info.m_name;
+    Kwave::Plugin *plugin = factory->create<Kwave::Plugin>(this, args);
     Q_ASSERT(plugin);
     if (!plugin) {
 	qWarning("PluginManager::loadPlugin('%s'): out of memory", DBG(name));
@@ -234,7 +245,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
 	}
     } else {
 	// load previous parameters from config
-	QStringList last_params = loadPluginDefaults(name);
+	QStringList last_params = defaultParams(name);
 
 	// call the plugin's setup function
 	params = plugin->setup(last_params);
@@ -279,7 +290,7 @@ bool Kwave::PluginManager::canClose()
     Q_ASSERT(this->thread() == qApp->thread());
 
     if (!m_plugin_instances.isEmpty())
-	foreach (KwavePluginPointer plugin, m_plugin_instances)
+	foreach (const KwavePluginPointer &plugin, m_plugin_instances)
 	    if (plugin && !plugin->canClose()) return false;
 
     return true;
@@ -293,7 +304,7 @@ bool Kwave::PluginManager::onePluginRunning()
     Q_ASSERT(this->thread() == qApp->thread());
 
     if (!m_plugin_instances.isEmpty())
-	foreach (KwavePluginPointer plugin, m_plugin_instances)
+	foreach (const KwavePluginPointer &plugin, m_plugin_instances)
 	    if (plugin && plugin->isRunning()) return true;
 
     return false;
@@ -306,6 +317,12 @@ void Kwave::PluginManager::sync()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
+    // this triggers all kinds of garbage collector (objects queued for
+    // deletion through obj->deleteLater()
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+    qApp->flush();
+
+    // wait until all plugins have finished their work...
     while (onePluginRunning()) {
 	Kwave::yield();
 	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
@@ -323,8 +340,8 @@ int Kwave::PluginManager::setupPlugin(const QString &name,
     if (!plugin) return -ENOMEM;
 
     // now the plugin is present and loaded
-    QStringList prev_params = (!params.isEmpty()) ?
-	params : loadPluginDefaults(name);
+    QStringList prev_params = (params.isEmpty()) ?
+	defaultParams(name) : params;
 
     // call the plugins' setup function
     QStringList *new_params = plugin->setup(prev_params);
@@ -343,7 +360,7 @@ int Kwave::PluginManager::setupPlugin(const QString &name,
 }
 
 //***************************************************************************
-QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name)
+QStringList Kwave::PluginManager::defaultParams(const QString &name)
 {
     QString def_version;
     QString section = _("plugin ");
@@ -355,9 +372,9 @@ QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name)
     const PluginModule &info = m_plugin_modules[name];
     QString version = info.m_version;
 
-    Q_ASSERT(KGlobal::config());
-    if (!KGlobal::config()) return list;
-    KConfigGroup cfg = KGlobal::config()->group(section);
+    Q_ASSERT(KSharedConfig::openConfig());
+    if (!KSharedConfig::openConfig()) return list;
+    KConfigGroup cfg = KSharedConfig::openConfig()->group(section);
 
     cfg.sync();
 
@@ -366,7 +383,7 @@ QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name)
 	return list;
     }
     if (!(def_version == version)) {
-	qDebug("PluginManager::loadPluginDefaults: "
+	qDebug("PluginManager::defaultParams: "
 	    "plugin '%s': defaults for version '%s' not loaded, found "
 	    "old ones of version '%s'.",
 	    DBG(name), DBG(version), DBG(def_version));
@@ -395,13 +412,13 @@ void Kwave::PluginManager::savePluginDefaults(const QString &name,
     QString section = _("plugin ");
     section += name;
 
-    Q_ASSERT(KGlobal::config());
-    if (!KGlobal::config()) return;
-    KConfigGroup cfg = KGlobal::config()->group(section);
+    Q_ASSERT(KSharedConfig::openConfig());
+    if (!KSharedConfig::openConfig()) return;
+    KConfigGroup cfg = KSharedConfig::openConfig()->group(section);
 
     cfg.sync();
     cfg.writeEntry("version", version);
-    cfg.writeEntry("defaults", params);
+    cfg.writeEntry("defaults", params.join(QLatin1Char(',')));
     cfg.sync();
 }
 
@@ -587,14 +604,6 @@ void Kwave::PluginManager::setSignalName(const QString &name)
 //***************************************************************************
 void Kwave::PluginManager::searchPluginModules()
 {
-    // hardcoded, should always work when the
-    // symbols are declared as extern "C"
-    const char *sym_name        = "name";
-    const char *sym_version     = "version";
-    const char *sym_description = "description";
-    const char *sym_author      = "author";
-    const char *sym_loader      = "load";
-
     if (!m_plugin_modules.isEmpty()) {
 	// this is not the first call -> increment module use count only
 	foreach (const QString &name, m_plugin_modules.keys()) {
@@ -604,67 +613,62 @@ void Kwave::PluginManager::searchPluginModules()
 	return;
     }
 
-    KStandardDirs dirs;
-    QStringList files = dirs.findAllResources("module",
-	    _("plugins/kwave/*"), KStandardDirs::NoDuplicates);
+    KPluginInfo::List plugins = KPluginTrader::self()->query(
+	_("kwave"), _("Kwave/Plugin")
+    );
+    foreach (const KPluginInfo &i, plugins) {
+	QString library     = i.libraryPath();
+	QString description = i.name();
+	QString name        = i.pluginName();
+	QString version_raw = i.version();
+	QString version;
+	QString settings;
+	QString author      = i.author();
 
-    /* fallback: search also in the old location (useful for developers) */
-    files += dirs.findAllResources("data",
-	    _("kwave/plugins/*"), KStandardDirs::NoDuplicates);
+	if (version_raw.contains(_(":"))) {
+	    version  = version_raw.split(_(":")).at(0);
+	    settings = version_raw.split(_(":")).at(1);
+	}
 
-    foreach (const QString &file, files) {
-	QLibrary *module = new QLibrary(file);
-	if (!module) continue;
+// 	qDebug("file='%s', name='%s', description='%s', binary_version='%s', "
+// 	       "settings_version='%s', author='%s'",
+// 	       DBG(library), DBG(name), DBG(description), DBG(version),
+// 	       DBG(settings), DBG(author)
+// 	);
 
-	module->setLoadHints(QLibrary::ResolveAllSymbolsHint);
-	if (!module->load()) {
-	    qWarning("error in '%s':\n\t %s",
-	             DBG(file), DBG(module->errorString()));
-	    delete module;
+	if ( library.isEmpty() || description.isEmpty() ||
+	     name.isEmpty() || version.isEmpty() ) {
+	    qWarning("plugin '%s' has no library, name or version", DBG(name));
 	    continue;
 	}
 
-	// get all required symbols from the plugin
-	const char **p_name    =
-	    static_cast<const char **>(module->resolve(sym_name));
-	const char **p_version =
-	    static_cast<const char **>(module->resolve(sym_version));
-	const char **p_description =
-	    static_cast<const char **>(module->resolve(sym_description));
-	const char **p_author  =
-	    static_cast<const char **>(module->resolve(sym_author));
-
-	void *p = module->resolve(sym_loader);
-	plugin_ldr_func_t *p_loader = 0;
-	memcpy(&p_loader, &p, sizeof(p));
-
-	// skip the plugin if something is missing or null
-	if (!p_name || !p_version || !p_author ||
-	    !p_description || !p_loader ||
-	    !*p_name || !*p_version || !*p_author ||
-	    !*p_description || !*p_loader)
-	{
-	    qWarning("WARNING: plugin %s is broken", DBG(file));
-	    delete module;
+	if (version != _(PACKAGE_SHORT_VERSION)) {
+	    qWarning("plugin '%s' has wrong ABI version: '%s' (should be %s)",
+	             DBG(name), DBG(version), PACKAGE_SHORT_VERSION);
 	    continue;
 	}
 
-	emit sigProgress(i18n("Loading plugin %1...", _(*p_name)));
+	KPluginLoader loader(library);
+	KPluginFactory* factory = loader.factory();
+	if (!factory) {
+	    qWarning("plugin '%s': loading failed", DBG(name));
+	    continue;
+	}
+
+	emit sigProgress(i18n("Loading plugin %1...", name));
 	QApplication::processEvents();
 
 	PluginModule info;
-	info.m_name        = QString::fromUtf8(*p_name);
-	info.m_author      = QString::fromUtf8(*p_author);
-	info.m_description = i18n(*p_description);
-	info.m_version     = QString::fromUtf8(*p_version);
-	info.m_loader      = p_loader;
-
-	info.m_module      = module;
+	info.m_name        = name;
+	info.m_author      = author;
+	info.m_description = i18n(description.toUtf8());
+	info.m_version     = settings;
+	info.m_factory     = factory;
 	info.m_use_count   = 1;
 
 	m_plugin_modules.insert(info.m_name, info);
 
-	qDebug("%16s %5s written by %s", *p_name, *p_version, *p_author);
+	qDebug("%16s %5s written by %s", DBG(name), DBG(settings), DBG(author));
     }
 
     qDebug("--- \n found %d plugins\n", m_plugin_modules.count());
@@ -703,7 +707,5 @@ void Kwave::PluginManager::migratePluginToActiveContext(Kwave::Plugin *plugin)
     plugin->setPluginManager(new_mgr);
 }
 
-//***************************************************************************
-#include "PluginManager.moc"
 //***************************************************************************
 //***************************************************************************
