@@ -20,9 +20,8 @@
 
 #include "config.h"
 
-#include <QtCore/QObject>
-
-#include <kdemacros.h>
+#include <QtGlobal>
+#include <QObject>
 
 #include "libkwave/SampleArray.h"
 #include "libkwave/modules/StreamObject.h"
@@ -30,7 +29,7 @@
 namespace Kwave
 {
 
-    class KDE_EXPORT SampleSink: public Kwave::StreamObject
+    class Q_DECL_EXPORT SampleSink: public Kwave::StreamObject
     {
         Q_OBJECT
     public:
