@@ -20,7 +20,7 @@
 
 #include "config.h"
 
-#include <kdemacros.h>
+#include <QtGlobal>
 
 #include "libkwave/Curve.h"
 #include "libkwave/SampleSource.h"
@@ -28,7 +28,7 @@
 namespace Kwave
 {
 
-    class KDE_EXPORT CurveStreamAdapter :public Kwave::SampleSource
+    class Q_DECL_EXPORT CurveStreamAdapter: public Kwave::SampleSource
     {
         Q_OBJECT
     public:
