@@ -20,14 +20,14 @@
 
 #include "config.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace Kwave
 {
 
     class UndoTransaction;
 
-    class UndoHandler : public QObject
+    class UndoHandler: public QObject
     {
     public:
 
