@@ -31,15 +31,16 @@ namespace Kwave
 	Q_OBJECT
     public:
 
-	/** Constructor */
-	explicit AsciiCodecPlugin(Kwave::PluginManager &plugin_manager);
+	/**
+	 * Constructor
+	 * @param parent reference to our plugin manager
+	 * @param args argument list [unused]
+	 */
+	AsciiCodecPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
 	virtual ~AsciiCodecPlugin();
 
-	/** Returns the name of the plugin. */
-	virtual QString name() const;
-
 	/** Creates a new decoder instance */
 	virtual Kwave::Decoder *createDecoder();
 
