@@ -20,17 +20,18 @@
 
 #include <audiofile.h>
 
-#include <QtCore/QtEndian>
-#include <QtCore/QtGlobal>
-#include <QtCore/QList>
-#include <QtCore/QVector>
+#include <QList>
+#include <QVector>
+#include <QtEndian>
+#include <QtGlobal>
 
-#include <QtGui/QApplication>
-#include <QtGui/QProgressDialog>
+#include <QApplication>
+#include <QMimeType>
+#include <QProgressDialog>
 
-#include <klocale.h>
-#include <kmimetype.h>
+#include <KLocalizedString>
 
+#include "libkwave/Compression.h"
 #include "libkwave/ConfirmCancelProxy.h"
 #include "libkwave/Label.h"
 #include "libkwave/LabelList.h"
@@ -39,17 +40,18 @@
 #include "libkwave/MetaDataList.h"
 #include "libkwave/MultiWriter.h"
 #include "libkwave/Sample.h"
+#include "libkwave/SampleFormat.h"
 #include "libkwave/String.h"
 #include "libkwave/Utils.h"
 #include "libkwave/VirtualAudioFile.h"
 #include "libkwave/Writer.h"
 
+#include "RIFFChunk.h"
+#include "RIFFParser.h"
 #include "RecoveryBuffer.h"
 #include "RecoveryMapping.h"
 #include "RecoverySource.h"
 #include "RepairVirtualAudioFile.h"
-#include "RIFFChunk.h"
-#include "RIFFParser.h"
 #include "WavDecoder.h"
 #include "WavFileFormat.h"
 #include "WavFormatMap.h"
@@ -397,19 +399,41 @@ bool Kwave::WavDecoder::open(QWidget *widget, QIODevice &src)
     AFframecount length = afGetFrameCount(fh, AF_DEFAULT_TRACK);
     tracks = afGetVirtualChannels(fh, AF_DEFAULT_TRACK);
 
-    int sample_format;
-    afGetVirtualSampleFormat(fh, AF_DEFAULT_TRACK, &sample_format,
+    int af_sample_format;
+    afGetVirtualSampleFormat(fh, AF_DEFAULT_TRACK, &af_sample_format,
 	reinterpret_cast<int *>(&bits));
-
-    int compression = afGetCompression(fh, AF_DEFAULT_TRACK);
     if (static_cast<signed int>(bits) < 0) bits = 0;
+    Kwave::SampleFormat::Format fmt;
+    switch (af_sample_format)
+    {
+	case AF_SAMPFMT_TWOSCOMP:
+	    fmt = Kwave::SampleFormat::Signed;
+	    break;
+	case AF_SAMPFMT_UNSIGNED:
+	    fmt = Kwave::SampleFormat::Unsigned;
+	    break;
+	case AF_SAMPFMT_FLOAT:
+	    fmt = Kwave::SampleFormat::Float;
+	    break;
+	case AF_SAMPFMT_DOUBLE:
+	    fmt = Kwave::SampleFormat::Double;
+	    break;
+	default:
+	    fmt = Kwave::SampleFormat::Unknown;
+	    break;
+    }
+
+    int af_compression = afGetCompression(fh, AF_DEFAULT_TRACK);
+    const Kwave::Compression compression(
+	Kwave::Compression::fromAudiofile(af_compression)
+    );
 
     info.setRate(rate);
     info.setBits(bits);
     info.setTracks(tracks);
     info.setLength(length);
-    info.set(Kwave::INF_SAMPLE_FORMAT, sample_format);
-    info.set(Kwave::INF_COMPRESSION, compression);
+    info.set(Kwave::INF_SAMPLE_FORMAT, Kwave::SampleFormat(fmt).toInt());
+    info.set(Kwave::INF_COMPRESSION, compression.toInt());
 
     // read in all info from the LIST (INFO) chunk
     Kwave::RIFFChunk *info_chunk = parser.findChunk("/RIFF:WAVE/LIST:INFO");
