@@ -19,8 +19,8 @@
 #define FILE_INFO_PLUGIN_H
 
 #include "config.h"
-#include <QtCore/QObject>
 #include "libkwave/Plugin.h"
+#include <QObject>
 
 namespace Kwave
 {
@@ -29,15 +29,16 @@ namespace Kwave
 	Q_OBJECT
     public:
 
-	/** Constructor */
-	explicit FileInfoPlugin(Kwave::PluginManager &plugin_manager);
+	/**
+	 * Constructor
+	 * @param parent reference to our plugin manager
+	 * @param args argument list [unused]
+	 */
+	FileInfoPlugin(QObject *parent, const QVariantList &args);
 
 	/** virtual Destructor */
 	virtual ~FileInfoPlugin();
 
-	/** Returns the name of the plugin. */
-	virtual QString name() const;
-
 	/**
 	* Shows a dialog for editing file properties.
 	* @see Kwave::Plugin::setup
