@@ -27,16 +27,15 @@
 #include <pulse/error.h>
 #include <pulse/gccmacro.h>
 #include <pulse/introspect.h>
+#include <pulse/mainloop.h>
 #include <pulse/proplist.h>
 #include <pulse/stream.h>
-#include <pulse/mainloop.h>
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtCore/QMutex>
-#include <QtCore/QSemaphore>
-#include <QtCore/QString>
-#include <QtCore/QWaitCondition>
+#include <QList>
+#include <QMap>
+#include <QMutex>
+#include <QString>
+#include <QWaitCondition>
 
 #include "libkwave/FileInfo.h"
 #include "libkwave/PlayBackDevice.h"
