@@ -20,11 +20,11 @@
 
 #include "config.h"
 
-#include <QtCore/QMutex>
-#include <QtCore/QString>
+#include <QMutex>
+#include <QString>
 
-#include "libkwave/PlaybackDeviceFactory.h"
 #include "libkwave/PlayBackParam.h"
+#include "libkwave/PlaybackDeviceFactory.h"
 #include "libkwave/Plugin.h"
 #include "libkwave/Sample.h"
 
@@ -44,15 +44,16 @@ namespace Kwave
 	Q_OBJECT
     public:
 
-	/** Constructor */
-	explicit PlayBackPlugin(Kwave::PluginManager &plugin_manager);
+	/**
+	 * Constructor
+	 * @param parent reference to our plugin manager
+	 * @param args argument list [unused]
+	 */
+	PlayBackPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
 	virtual ~PlayBackPlugin();
 
-	/** Returns the name of the plugin. */
-	virtual QString name() const;
-
 	/**
 	 * Gets called when the plugin is first loaded and connects itself
 	 * to the playback controller and the current signal.
