@@ -18,19 +18,19 @@
 #include "config.h"
 #ifdef HAVE_OSS_SUPPORT
 
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <math.h>
 #include <sys/ioctl.h>
 #include <sys/soundcard.h>
-#include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
-#include <math.h>
-#include <errno.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QLatin1Char>
-#include <QtCore/QtGlobal>
+#include <QDir>
+#include <QFile>
+#include <QLatin1Char>
+#include <QtGlobal>
 
 #include "libkwave/Compression.h"
 #include "libkwave/SampleFormat.h"
@@ -87,18 +87,34 @@ Kwave::RecordOSS::~RecordOSS()
 }
 
 //***************************************************************************
-int Kwave::RecordOSS::open(const QString &dev)
+QString Kwave::RecordOSS::open(const QString &dev)
 {
     // close the device if it is still open
     if (m_fd >= 0) close();
-    if (!dev.length()) return -1; // no device name
+    if (!dev.length()) return QString::number(EINVAL); // no device name
 
     // first of all: try to open the device itself
     int fd = ::open(dev.toLocal8Bit(), O_RDONLY | O_NONBLOCK);
     if (fd < 0) {
 	qWarning("open failed, fd=%d, errno=%d (%s)",
 	         fd, errno, strerror(errno));
-	return -errno;
+
+	QString reason;
+	switch (errno) {
+	    case ENOENT:
+	    case ENODEV:
+	    case ENXIO:
+	    case EIO:
+		reason = QString::number(ENODEV);
+		break;
+	    case EBUSY:
+		reason = QString::number(EBUSY);
+		break;
+	    default:
+		reason = i18n(strerror(errno));
+		break;
+	}
+	return reason;
     }
 
     // Query OSS driver version
@@ -107,7 +123,7 @@ int Kwave::RecordOSS::open(const QString &dev)
     ioctl(fd, OSS_GETVERSION, &m_oss_version);
 #endif
     m_fd = fd;
-    return m_fd;
+    return QString::null;
 }
 
 //***************************************************************************
@@ -175,7 +191,7 @@ int Kwave::RecordOSS::read(QByteArray &buffer, unsigned int offset)
 	             errno, strerror(errno));
 	    return -errno;
 	} else if (retval) {
-	    int res = ::read(m_fd, buf, length);
+	    ssize_t res = ::read(m_fd, buf, length);
 
 	    if ((res == -1) && (errno == EINTR))
 		return -errno; // interrupted, return without warning
@@ -464,7 +480,9 @@ double Kwave::RecordOSS::sampleRate()
 }
 
 //***************************************************************************
-void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
+void Kwave::RecordOSS::format2mode(int format,
+                                   Kwave::Compression::Type &compression,
+                                   int &bits,
                                    Kwave::SampleFormat::Format &sample_format)
 {
 
@@ -489,7 +507,7 @@ void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
 	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 8;
 	    break;
-	case AFMT_S16_LE:
+	case AFMT_S16_LE: /* FALLTHROUGH */
 	case AFMT_S16_BE:
 	    compression   = Kwave::Compression::NONE;
 	    sample_format = Kwave::SampleFormat::Signed;
@@ -500,15 +518,14 @@ void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
 	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 8;
 	    break;
-	case AFMT_U16_LE:
+	case AFMT_U16_LE: /* FALLTHROUGH */
 	case AFMT_U16_BE:
 	    compression   = Kwave::Compression::NONE;
 	    sample_format = Kwave::SampleFormat::Unsigned;
 	    bits          = 16;
 	    break;
 	case AFMT_MPEG:
-	    compression   = static_cast<int>(
-	                    Kwave::Compression::MPEG_LAYER_II);
+	    compression   = Kwave::Compression::MPEG_LAYER_II;
 	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 16;
 	    break;
@@ -519,20 +536,20 @@ void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
 	    bits          = 16;
 	    break;
 #endif
-	case AFMT_S24_LE:
+	case AFMT_S24_LE: /* FALLTHROUGH */
 	case AFMT_S24_BE:
 	    compression   = Kwave::Compression::NONE;
 	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 24;
 	    break;
-	case AFMT_S32_LE:
+	case AFMT_S32_LE: /* FALLTHROUGH */
 	case AFMT_S32_BE:
 	    compression   = Kwave::Compression::NONE;
 	    sample_format = Kwave::SampleFormat::Signed;
 	    bits          = 32;
 	    break;
 	default:
-	    compression   = -1;
+	    compression   = Kwave::Compression::NONE;
 	    sample_format = Kwave::SampleFormat::Unknown;
 	    bits          = -1;
     }
@@ -540,7 +557,8 @@ void Kwave::RecordOSS::format2mode(int format, int &compression, int &bits,
 }
 
 //***************************************************************************
-int Kwave::RecordOSS::mode2format(int compression, int bits,
+int Kwave::RecordOSS::mode2format(Kwave::Compression::Type compression,
+                                  int bits,
                                   Kwave::SampleFormat::Format sample_format)
 {
     // first level: compression
@@ -610,18 +628,17 @@ int Kwave::RecordOSS::mode2format(int compression, int bits,
 }
 
 //***************************************************************************
-QList<int> Kwave::RecordOSS::detectCompressions()
+QList<Kwave::Compression::Type> Kwave::RecordOSS::detectCompressions()
 {
     Q_ASSERT(m_fd >= 0);
-    QList<int> compressions;
+    QList<Kwave::Compression::Type> compressions;
     int err = 0;
     int mask = AFMT_QUERY;
 
     err = ioctl(m_fd, SNDCTL_DSP_GETFMTS, &mask);
     if (err < 0) return compressions;
 
-    if (mask & AFMT_MPEG)
-        compressions += static_cast<int>(Kwave::Compression::MPEG_LAYER_II);
+    if (mask & AFMT_MPEG)    compressions += Kwave::Compression::MPEG_LAYER_II;
     if (mask & AFMT_A_LAW)   compressions += Kwave::Compression::G711_ALAW;
     if (mask & AFMT_MU_LAW)  compressions += Kwave::Compression::G711_ULAW;
     if (mask & AFMT_IMA_ADPCM) compressions += Kwave::Compression::MS_ADPCM;
@@ -634,15 +651,16 @@ QList<int> Kwave::RecordOSS::detectCompressions()
 }
 
 //***************************************************************************
-int Kwave::RecordOSS::setCompression(int new_compression)
+int Kwave::RecordOSS::setCompression(Kwave::Compression::Type new_compression)
 {
     Q_ASSERT(m_fd >= 0);
-    int compression, bits, format = AFMT_QUERY;
+    Kwave::Compression::Type compression;
+    int bits, format = AFMT_QUERY;
     Kwave::SampleFormat::Format sample_format;
 
     // read back current format
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &format);
-    if (err < 0) return err;
+    if (err < 0) return -1;
     format2mode(format, compression, bits, sample_format);
 
     // modify the compression
@@ -650,23 +668,22 @@ int Kwave::RecordOSS::setCompression(int new_compression)
 
     // activate new format
     format = mode2format(compression, bits, sample_format);
-    int oldformat = format;
     err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &format);
-    if (err < 0) return err;
-    if (oldformat != format) return -1;
+    if (err < 0) return -1;
 
     return 0;
 }
 
 //***************************************************************************
-int Kwave::RecordOSS::compression()
+Kwave::Compression::Type Kwave::RecordOSS::compression()
 {
     Q_ASSERT(m_fd >= 0);
     int mask = AFMT_QUERY;
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
     if (err < 0) return Kwave::Compression::NONE;
 
-    int c, b;
+    Kwave::Compression::Type c;
+    int b;
     Kwave::SampleFormat::Format s;
     format2mode(mask, c, b, s);
     return c;
@@ -690,7 +707,8 @@ QList<unsigned int> Kwave::RecordOSS::supportedBits()
 	if (!(mask & (1 << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
-	int c, b;
+	Kwave::Compression::Type c(Kwave::Compression::NONE);
+	int b;
 	Kwave::SampleFormat::Format s;
 	format2mode(1 << bit, c, b, s);
 	if (b < 0) continue; // unknown -> skip
@@ -713,7 +731,8 @@ QList<unsigned int> Kwave::RecordOSS::supportedBits()
 int Kwave::RecordOSS::setBitsPerSample(unsigned int new_bits)
 {
     Q_ASSERT(m_fd >= 0);
-    int compression, bits, format = AFMT_QUERY;
+    Kwave::Compression::Type compression;
+    int bits, format = AFMT_QUERY;
     Kwave::SampleFormat::Format sample_format;
 
     // read back current format
@@ -742,7 +761,8 @@ int Kwave::RecordOSS::bitsPerSample()
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
     if (err < 0) return err;
 
-    int c, b;
+    Kwave::Compression::Type c;
+    int b;
     Kwave::SampleFormat::Format s;
     format2mode(mask, c, b, s);
     return b;
@@ -762,13 +782,14 @@ QList<Kwave::SampleFormat::Format> Kwave::RecordOSS::detectSampleFormats()
 
     // mask out all modes that do not match the current compression
     // and bits per sample
-    const int compression     = this->compression();
+    const Kwave::Compression::Type compression = this->compression();
     const int bits_per_sample = this->bitsPerSample();
     for (unsigned int bit = 0; bit < (sizeof(mask) << 3); bit++) {
 	if (!(mask & (1 << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
-	int c, b;
+	Kwave::Compression::Type c;
+	int b;
 	Kwave::SampleFormat::Format s;
 	format2mode(1 << bit, c, b, s);
 	if (c < 0) continue; // unknown -> skip
@@ -786,7 +807,8 @@ QList<Kwave::SampleFormat::Format> Kwave::RecordOSS::detectSampleFormats()
 int Kwave::RecordOSS::setSampleFormat(Kwave::SampleFormat::Format new_format)
 {
     Q_ASSERT(m_fd >= 0);
-    int compression, bits, format = AFMT_QUERY;
+    Kwave::Compression::Type compression;
+    int bits, format = AFMT_QUERY;
     Kwave::SampleFormat::Format sample_format;
 
     // read back current format
@@ -815,7 +837,8 @@ Kwave::SampleFormat::Format Kwave::RecordOSS::sampleFormat()
     int err = ioctl(m_fd, SNDCTL_DSP_SETFMT, &mask);
     if (err < 0) return Kwave::SampleFormat::Unknown;
 
-    int c, b;
+    Kwave::Compression::Type c;
+    int b;
     Kwave::SampleFormat::Format s;
     format2mode(mask, c, b, s);
     return s;
