@@ -19,15 +19,16 @@
 
 #include <errno.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QStringList>
-#include <QtCore/QRegExp>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QRegExp>
+#include <QStringList>
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "libkwave/CodecManager.h"
+#include "libkwave/FileInfo.h"
 #include "libkwave/Label.h"
 #include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
@@ -39,14 +40,14 @@
 #include "SaveBlocksDialog.h"
 #include "SaveBlocksPlugin.h"
 
-KWAVE_PLUGIN(Kwave::SaveBlocksPlugin, "saveblocks", "2.4",
-             I18N_NOOP("Save Blocks"), "Thomas Eschenbacher");
+KWAVE_PLUGIN(saveblocks, SaveBlocksPlugin)
 
 //***************************************************************************
-Kwave::SaveBlocksPlugin::SaveBlocksPlugin(Kwave::PluginManager &plugin_manager)
-    :Kwave::Plugin(plugin_manager),
+Kwave::SaveBlocksPlugin::SaveBlocksPlugin(QObject *parent,
+                                          const QVariantList &args)
+    :Kwave::Plugin(parent, args),
      m_url(), m_pattern(), m_numbering_mode(CONTINUE),
-     m_selection_only(true)
+     m_selection_only(true), m_block_info()
 {
 }
 
@@ -58,7 +59,7 @@ Kwave::SaveBlocksPlugin::~SaveBlocksPlugin()
 //***************************************************************************
 QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
 {
-    // try to interprete the previous parameters
+    // try to interpret the previous parameters
     interpreteParameters(previous_params);
 
     // create the setup dialog
@@ -73,12 +74,17 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
                          (selection_right + 1 >= signalLength()));
     bool enable_selection_only = selected_something && !selected_all;
 
+    QString filename = m_url.path();
+    QString base = findBase(filename, m_pattern);
+    scanBlocksToSave(base, m_selection_only && enable_selection_only);
+
     QPointer<Kwave::SaveBlocksDialog> dialog =
 	new(std::nothrow) Kwave::SaveBlocksDialog(
 	    _("kfiledialog:///kwave_save_blocks"),
 	    Kwave::CodecManager::encodingFilter(),
-	    parentWidget(), true,
-	    signalName(), _("*.wav"),
+	    parentWidget(),
+	    QUrl::fromUserInput(signalName()),
+	    _("*.wav"),
 	    m_pattern,
 	    m_numbering_mode,
 	    m_selection_only,
@@ -94,9 +100,12 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     connect(this, SIGNAL(sigNewExample(QString)),
 	dialog, SLOT(setNewExample(QString)));
 
-    dialog->setCaption(i18n("Save Blocks"));
+    dialog->setWindowTitle(i18n("Save Blocks"));
     dialog->emitUpdate();
-    if (dialog->exec() != QDialog::Accepted) return 0;
+    if (dialog->exec() != QDialog::Accepted) {
+	delete dialog;
+	return 0;
+    }
 
     QStringList *list = new QStringList();
     Q_ASSERT(list);
@@ -104,7 +113,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
 	// user has pressed "OK"
 	QString pattern;
 
-	KUrl url = dialog->selectedUrl();
+	QUrl url = dialog->selectedUrl();
 	if (url.isEmpty()) {
 	    delete dialog;
 	    return 0;
@@ -148,6 +157,31 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     return list;
 }
 
+//***************************************************************************
+QString Kwave::SaveBlocksPlugin::createDisplayList(
+    const QStringList &list,
+    unsigned int max_entries) const
+{
+    if (!max_entries || list.isEmpty()) return QString();
+
+    QString retval;
+    unsigned int count = 0;
+
+    foreach (const QString &entry, list) {
+	if (count == 0) // first entry
+	    retval = _("<br><br>");
+	if (count < max_entries)
+	    retval += entry + _("<br>");
+	else if (count == max_entries)
+	    retval += i18n("...") + _("<br>");
+
+	if (++count > max_entries)
+	    break;
+    }
+
+    return retval;
+}
+
 //***************************************************************************
 int Kwave::SaveBlocksPlugin::start(QStringList &params)
 {
@@ -157,11 +191,12 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     int result = interpreteParameters(params);
     if (result) return result;
 
-    QString filename = m_url.prettyUrl();
+    QString filename = m_url.path();
     QFileInfo file(filename);
     QString path = file.absolutePath();
     QString ext  = file.suffix();
     QString base = findBase(filename, m_pattern);
+    QByteArray sep("/");
 
     // determine the selection settings
     sample_index_t selection_left  = 0;
@@ -182,7 +217,8 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     }
 
     // get the index range
-    unsigned int count = blocksToSave(selection_only);
+    scanBlocksToSave(base, selection_only);
+    unsigned int count = m_block_info.count();
     unsigned int first = firstIndex(path, base, ext, m_pattern,
                                     m_numbering_mode, count);
 
@@ -192,50 +228,81 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
 //     qDebug("selection_only   = %d", selection_only);
 //     qDebug("indices          = %u...%u (count=%u)", first, first+count-1,count);
 
-    // check for filenames that might be overwritten
-    const int max_overwrite_list_length = 7;
-    QDir dir(path, _("*"));
-    QStringList files;
-    files = dir.entryList();
-    QStringList overwritten;
-    for (unsigned int i = first; i < first+count; i++) {
+    // iterate over all blocks to check for overwritten files and missing dirs
+    QStringList  overwritten_files;
+    QStringList  missing_dirs;
+    for (unsigned int i = first; i < (first + count); i++) {
 	QString name = createFileName(base, ext, m_pattern, i, count,
 	                              first + count - 1);
-	QRegExp rx(_("^(") + QRegExp::escape(name) + _(")$"),
-	           Qt::CaseInsensitive);
-	QStringList matches = files.filter(rx);
-	if (matches.count() > 0) {
-	    overwritten += name;
-	    if (overwritten.count() > max_overwrite_list_length)
-		break; // we have collected enough names...
+	QString display_name = Kwave::Parser::unescape(name);
+
+	// split the name into directory and file name
+	name = QString::fromLatin1(QUrl::toPercentEncoding(display_name, sep));
+	QUrl url = m_url.adjusted(QUrl::RemoveFilename);
+	url.setPath(url.path(QUrl::FullyEncoded) + name, QUrl::StrictMode);
+
+	QString filename = url.path();
+	QFileInfo file_info(filename);
+
+	// check for potentially overwritten file
+	if (file_info.exists())
+	    overwritten_files += Kwave::Parser::unescape(display_name);
+
+	// check for missing subdirectory
+	if (!file_info.dir().exists()) {
+	    QFileInfo inf(display_name);
+	    QString missing_dir = inf.path();
+	    if (!missing_dirs.contains(missing_dir))
+		missing_dirs += missing_dir;
 	}
     }
-    if (overwritten.count()) {
+
+    // inform about overwritten files
+    if (!overwritten_files.isEmpty()) {
 	// ask the user for confirmation if he really wants to overwrite...
-
-	QString list = _("<br><br>");
-	int cnt = 0;
-	for (QStringList::Iterator it = overwritten.begin();
-	     it != overwritten.end() && (cnt <= max_overwrite_list_length);
-	     ++it, ++cnt)
-	{
-	    list += (*it);
-	    list += _("<br>");
-	}
-	if (overwritten.count() > max_overwrite_list_length)
-	    list += i18n("...");
-	list += _("<br>");
-
 	if (Kwave::MessageBox::warningYesNo(parentWidget(),
 	    _("<html>") +
 	    i18n("This would overwrite the following file(s): %1" \
 	    "Do you really want to continue?",
-	    list) + _("</html>")) != KMessageBox::Yes)
+	    createDisplayList(overwritten_files, 5)) +
+	    _("</html>") ) != KMessageBox::Yes)
 	{
 	    return -1;
 	}
     }
 
+    // handle missing directories
+    if (!missing_dirs.isEmpty()) {
+	// ask the user if he wants to continue and create the directory
+	if (Kwave::MessageBox::warningContinueCancel(parentWidget(),
+	    i18n("The following directories do not exist: %1"
+	         "Do you want to create them and continue?",
+	         createDisplayList(missing_dirs, 5)),
+	    QString(),
+	    QString(),
+	    QString(),
+	    _("saveblocks_create_missing_dirs")
+	    ) != KMessageBox::Continue)
+	{
+	    return -1;
+	}
+
+	// create all missing directories
+	QUrl base_url = m_url.adjusted(QUrl::RemoveFilename);
+	foreach (const QString &missing, missing_dirs) {
+	    QUrl url(base_url);
+	    url.setPath(
+		base_url.path(QUrl::FullyEncoded) +
+		QString::fromLatin1(QUrl::toPercentEncoding(missing)),
+		QUrl::StrictMode
+	    );
+	    QString path = url.path();
+	    QDir dir;
+	    if (!dir.mkpath(path))
+		qWarning("creating path '%s' failed", DBG(path));
+	}
+    }
+
     // save the current selection, we have to restore it afterwards!
     sample_index_t saved_selection_left  = 0;
     sample_index_t saved_selection_right = 0;
@@ -269,14 +336,16 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
 	    // determine the filename
 	    QString name = createFileName(base, ext, m_pattern, index, count,
                                           first + count - 1);
-	    KUrl url = m_url;
-	    url.setFileName(name);
-	    filename = url.prettyUrl();
+	    name = Kwave::Parser::unescape(name);
+	    // use URL encoding for the filename
+	    name = QString::fromLatin1(QUrl::toPercentEncoding(name, sep));
+	    QUrl url = m_url.adjusted(QUrl::RemoveFilename);
+	    url.setPath(url.path(QUrl::FullyEncoded) + name, QUrl::StrictMode);
 
 	    qDebug("saving %9lu...%9lu -> '%s'",
 		   static_cast<unsigned long int>(left),
 		   static_cast<unsigned long int>(right),
-		   DBG(filename));
+		   DBG(url.toDisplayString()));
 	    if (signalManager().save(url, true) < 0)
 		break;
 
@@ -307,7 +376,7 @@ int Kwave::SaveBlocksPlugin::interpreteParameters(QStringList &params)
     }
 
     // the selected URL
-    m_url = Kwave::Parser::unescape(params[0]);
+    m_url = QUrl::fromUserInput(Kwave::Parser::unescape(params[0]));
     if (!m_url.isValid()) return -EINVAL;
 
     // filename pattern
@@ -333,13 +402,14 @@ int Kwave::SaveBlocksPlugin::interpreteParameters(QStringList &params)
 }
 
 //***************************************************************************
-unsigned int Kwave::SaveBlocksPlugin::blocksToSave(bool selection_only)
+void Kwave::SaveBlocksPlugin::scanBlocksToSave(const QString &base,
+                                               bool selection_only)
 {
-    unsigned int count = 0;
     sample_index_t selection_left, selection_right;
 
     sample_index_t block_start;
     sample_index_t block_end = 0;
+    QString        block_title;
     Kwave::LabelList labels(signalManager().metaData());
     Kwave::LabelListIterator it(labels);
     Kwave::Label label = (it.hasNext()) ? it.next() : Kwave::Label();
@@ -347,19 +417,39 @@ unsigned int Kwave::SaveBlocksPlugin::blocksToSave(bool selection_only)
     if (selection_only) {
 	selection(0, &selection_left, &selection_right, true);
     } else {
-	selection_left = 0;
+	selection_left  = 0;
 	selection_right = signalLength() - 1;
     }
+
+    // get the title of the whole file, in case that a block does not have
+    // an own title
+    FileInfo info(signalManager().metaData());
+    QString file_title = info.get(INF_NAME).toString();
+
+    // fallback: if there is no INF_NAME either, fall back to the file
+    //           name as last resort
+    if (!file_title.length()) file_title = base;
+
+    m_block_info.clear();
+    QString prev_title;
     for (;;) {
 	block_start = block_end;
 	block_end   = (label.isNull()) ? signalLength() : label.pos();
-	if ((selection_left < block_end) && (selection_right > block_start))
-	    count++;
+	block_title = prev_title;
+	prev_title  = (label.isNull()) ? file_title     : label.name();
+
+	if ((block_end > selection_left) && (block_start <= selection_right)) {
+	    BlockInfo block;
+	    block.m_start  = block_start;
+	    block.m_length = block_end - block_start;
+	    block.m_title  = block_title;
+	    if (!block.m_title.length()) block.m_title = file_title;
+	    m_block_info.append(block);
+	}
+
 	if (label.isNull()) break;
 	label = (it.hasNext()) ? it.next() : Kwave::Label();
     }
-
-    return count;
 }
 
 //***************************************************************************
@@ -371,11 +461,14 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
     QString nr;
 
     // format the "index" parameter
-    QRegExp rx_nr(_("(\\\\\\[%\\d*nr\\\\\\])"), Qt::CaseInsensitive);
+    QRegExp rx_nr(_("(\\\\\\[%(\\d*)nr\\\\\\])"), Qt::CaseInsensitive);
     while (rx_nr.indexIn(p) >= 0) {
 	QString format = rx_nr.cap(1);
-	format = format.mid(2, format.length() - 6) + _("u");
-	p.replace(rx_nr, nr.sprintf(format.toAscii(), index));
+	format = format.mid(2, format.length() - 6);
+	QString ex = _("(\\\\\\[") + format + _("nr\\\\\\])");
+	QRegExp rx(ex, Qt::CaseInsensitive);
+	format += _("u");
+	p.replace(rx, nr.sprintf(format.toLatin1(), index));
     }
 
     // format the "count" parameter
@@ -383,8 +476,11 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
     while (rx_count.indexIn(p) >= 0) {
 	if (count >= 0) {
 	    QString format = rx_count.cap(1);
-	    format = format.mid(2, format.length() - 9) + _("u");
-	    p.replace(rx_count, nr.sprintf(format.toAscii(), count));
+	    format = format.mid(2, format.length() - 9);
+	    QString ex = _("(\\\\\\[") + format + _("count\\\\\\])");
+	    QRegExp rx(ex, Qt::CaseInsensitive);
+	    format += _("u");
+	    p.replace(rx, nr.sprintf(format.toLatin1(), count));
 	} else {
 	    p.replace(rx_count, _("(\\d+)"));
 	}
@@ -395,8 +491,11 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
     while (rx_total.indexIn(p) >= 0) {
 	if (total >= 0) {
 	    QString format = rx_total.cap(1);
-	    format = format.mid(2, format.length() - 9) + _("u");
-	    p.replace(rx_total, nr.sprintf(format.toAscii(), total));
+	    format = format.mid(2, format.length() - 9);
+	    QString ex = _("(\\\\\\[") + format + _("total\\\\\\])");
+	    QRegExp rx(ex, Qt::CaseInsensitive);
+	    format += _("u");
+	    p.replace(rx, nr.sprintf(format.toLatin1(), total));
 	} else {
 	    p.replace(rx_total, _("(\\d+)"));
 	}
@@ -408,7 +507,69 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
 	p.replace(rx_filename, QRegExp::escape(base));
     }
 
+    // support for file info
+    QRegExp rx_fileinfo(
+	_("\\\\\\[%(\\d*)fileinfo\\\\\\{([\\w\\s]+)\\\\\\}\\\\\\]"),
+	Qt::CaseInsensitive
+    );
+    Kwave::FileInfo info(signalManager().metaData());
+    while (rx_fileinfo.indexIn(p) >= 0) {
+	const QString format = rx_fileinfo.cap(1);
+	const QString id     = rx_fileinfo.cap(2);
+	QString value;
+	FileProperty property = info.fromName(id);
+	if (property != Kwave::INF_UNKNOWN) {
+	    QVariant val = info.get(property);
+	    if (!val.isNull()) {
+		// we have a property value
+		value = val.toString();
+
+		// check for format (desired minimum string length)
+		bool ok  = false;
+		int  len = format.toUInt(&ok);
+		if ((len > 0) && ok) {
+		    Kwave::FileInfo::Flags flags = info.flags(property);
+		    if (flags & Kwave::FileInfo::FP_FORMAT_NUMERIC) {
+			// numeric format, pad with leading zeros or spaces
+			QString pad = (format.startsWith(QLatin1Char('0'))) ?
+			    _("0") : _(" ");
+			while (value.length() < len)
+			    value = pad + value;
+		    } else {
+			// string format, pad with trailing spaces
+			while (value.length() < len)
+			    value = value + _(" ");
+		    }
+		}
+		value = Kwave::Parser::escape(value);
+	    }
+	}
+
+	QString ex(_("(\\\\\\[%") + format + _("fileinfo\\\\\\{") + id +
+	           _("\\\\\\}\\\\\\])"));
+	QRegExp rx(ex, Qt::CaseInsensitive);
+	p.replace(rx, value);
+    }
+
+    // format the "title" parameter
+    QRegExp rx_title(_("\\\\\\[%title\\\\\\]"), Qt::CaseInsensitive);
+    if (rx_title.indexIn(p) >= 0) {
+	QString title;
+	int idx = (index - 1) - (total - count);
+	if ((idx >= 0) && (idx < m_block_info.count()))
+	    title = m_block_info[idx].m_title;
+	if (title.length())
+	    p.replace(rx_title, QRegExp::escape(title));
+    }
+
     if (ext.length()) p += _(".") + ext;
+
+    // sanitize the filename/path, make sure that there are no spaces
+    // before and after all path separators
+    QString sep = _("/");
+    QRegExp rx_sep(_("\\s*") + sep + _("\\s*"));
+    p.replace(rx_sep, sep);
+
     return p;
 }
 
@@ -426,7 +587,7 @@ unsigned int Kwave::SaveBlocksPlugin::firstIndex(const QString &path,
 	    QDir dir(path, _("*"));
 	    QStringList files;
 	    files = dir.entryList();
-	    for (unsigned int i = first; i < first+count; i++) {
+	    for (unsigned int i = first; i < (first + count); i++) {
 		QString name = createFileName(base, ext, pattern, i, -1, -1);
 		QRegExp rx(_("^(") + name + _(")$"),
 		           Qt::CaseInsensitive);
@@ -455,31 +616,44 @@ QString Kwave::SaveBlocksPlugin::findBase(const QString &filename,
     // \[%[0-9]?count\]   -> \d+
     // \[%[0-9]?total\]   -> \d+
     // \[%filename\]      -> base
+    // \[%fileinfo\]      -> .
+    // \[%title\]         -> .
     QRegExp rx_nr(_("\\\\\\[%\\d*nr\\\\\\]"), Qt::CaseInsensitive);
     QRegExp rx_count(_("\\\\\\[%\\d*count\\\\\\]"), Qt::CaseInsensitive);
     QRegExp rx_total(_("\\\\\\[%\\d*total\\\\\\]"), Qt::CaseInsensitive);
     QRegExp rx_filename(_("\\\\\\[%filename\\\\\\]"), Qt::CaseInsensitive);
+    QRegExp rx_fileinfo(_("\\\\\\[%fileinfo\\\\\\]"), Qt::CaseInsensitive);
+    QRegExp rx_title(_("\\\\\\[%title\\\\\\]"), Qt::CaseInsensitive);
 
     QString p = QRegExp::escape(pattern);
-    int idx_nr = rx_nr.indexIn(p);
-    int idx_count = rx_count.indexIn(p);
-    int idx_total = rx_total.indexIn(p);
+    int idx_nr       = rx_nr.indexIn(p);
+    int idx_count    = rx_count.indexIn(p);
+    int idx_total    = rx_total.indexIn(p);
     int idx_filename = rx_filename.indexIn(p);
-    p.replace(rx_nr, _("(\\d+)"));
-    p.replace(rx_count, _("(\\d+)"));
-    p.replace(rx_total, _("(\\d+)"));
+    int idx_fileinfo = rx_fileinfo.indexIn(p);
+    int idx_title    = rx_fileinfo.indexIn(p);
+    p.replace(rx_nr,       _("(\\d+)"));
+    p.replace(rx_count,    _("(\\d+)"));
+    p.replace(rx_total,    _("(\\d+)"));
     p.replace(rx_filename, _("(.+)"));
+    p.replace(rx_fileinfo, _("(.+)"));
+    p.replace(rx_title,    _("(.+)"));
 
     int max = 0;
-    for (int i=0; i < pattern.length(); i++) {
+    for (int i = 0; i < pattern.length(); i++) {
 	if (idx_nr       == max) max++;
 	if (idx_count    == max) max++;
 	if (idx_total    == max) max++;
 	if (idx_filename == max) max++;
+	if (idx_fileinfo == max) max++;
+	if (idx_title    == max) max++;
+
 	if (idx_nr       > max) idx_nr--;
 	if (idx_count    > max) idx_count--;
 	if (idx_total    > max) idx_total--;
 	if (idx_filename > max) idx_filename--;
+	if (idx_fileinfo > max) idx_fileinfo--;
+	if (idx_title    > max) idx_title--;
     }
 
     if (ext.length()) p += _(".") + ext;
@@ -504,7 +678,8 @@ QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
 
     // now we have a new name, base and extension
     // -> find out the numbering, min/max etc...
-    unsigned int count = blocksToSave(selection_only);
+    scanBlocksToSave(base, selection_only);
+    unsigned int count = m_block_info.count();
     unsigned int first = firstIndex(path, base, ext, pattern, mode, count);
     unsigned int total = first + count - 1;
 
@@ -512,22 +687,13 @@ QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
     return createFileName(base, ext, pattern, first, count, total);
 }
 
-//***************************************************************************
-static QString unescape(const QString &s)
-{
-    QRegExp rx_single(_("\\\\(?!\\\\)"));
-    QString str = s;
-    str.replace(rx_single, _(""));
-    return str;
-}
-
 //***************************************************************************
 void Kwave::SaveBlocksPlugin::updateExample(const QString &filename,
     const QString &pattern, Kwave::SaveBlocksPlugin::numbering_mode_t mode,
     bool selection_only)
 {
     QString example = firstFileName(filename, pattern, mode, selection_only);
-    emit sigNewExample(unescape(example));
+    emit sigNewExample(Kwave::Parser::unescape(example));
 }
 
 //***************************************************************************
